==> zio-aws-transcribe_2.13-6.20.56.2-sources.jar: zio/aws/transcribe/model/UpdateVocabularyFilterResponse.scala <==
package zio.aws.transcribe.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.transcribe.model.primitives.{DateTime, VocabularyFilterName}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class UpdateVocabularyFilterResponse(
    vocabularyFilterName: Optional[VocabularyFilterName] = Optional.Absent,
    languageCode: Optional[zio.aws.transcribe.model.LanguageCode] =
      Optional.Absent,
    lastModifiedTime: Optional[DateTime] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse = {
    import UpdateVocabularyFilterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
      .builder()
      .optionallyWith(
        vocabularyFilterName.map(value =>
          VocabularyFilterName.unwrap(value): java.lang.String
        )
      )(_.vocabularyFilterName)
      .optionallyWith(languageCode.map(value => value.unwrap))(_.languageCode)
      .optionallyWith(
        lastModifiedTime.map(value => DateTime.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .build()
  }
  def asReadOnly
      : zio.aws.transcribe.model.UpdateVocabularyFilterResponse.ReadOnly =
    zio.aws.transcribe.model.UpdateVocabularyFilterResponse
      .wrap(buildAwsValue())
}
object UpdateVocabularyFilterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.transcribe.model.UpdateVocabularyFilterResponse =
      zio.aws.transcribe.model.UpdateVocabularyFilterResponse(
        vocabularyFilterName.map(value => value),
        languageCode.map(value => value),
        lastModifiedTime.map(value => value)
      )
    def vocabularyFilterName: Optional[VocabularyFilterName]
    def languageCode: Optional[zio.aws.transcribe.model.LanguageCode]
    def lastModifiedTime: Optional[DateTime]
    def getVocabularyFilterName: ZIO[Any, AwsError, VocabularyFilterName] =
      AwsError.unwrapOptionField("vocabularyFilterName", vocabularyFilterName)
    def getLanguageCode
        : ZIO[Any, AwsError, zio.aws.transcribe.model.LanguageCode] =
      AwsError.unwrapOptionField("languageCode", languageCode)
    def getLastModifiedTime: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
  ) extends zio.aws.transcribe.model.UpdateVocabularyFilterResponse.ReadOnly {
    override val vocabularyFilterName: Optional[VocabularyFilterName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vocabularyFilterName())
        .map(value =>
          zio.aws.transcribe.model.primitives.VocabularyFilterName(value)
        )
    override val languageCode: Optional[zio.aws.transcribe.model.LanguageCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.languageCode())
        .map(value => zio.aws.transcribe.model.LanguageCode.wrap(value))
    override val lastModifiedTime: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.lastModifiedTime())
      .map(value => zio.aws.transcribe.model.primitives.DateTime(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
  ): zio.aws.transcribe.model.UpdateVocabularyFilterResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-transcribe_3-5.17.145.1-sources.jar: zio/aws/transcribe/model/UpdateVocabularyFilterResponse.scala <==
package zio.aws.transcribe.model
import zio.ZIO
import zio.aws.transcribe.model.primitives.{DateTime, VocabularyFilterName}
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class UpdateVocabularyFilterResponse(
    vocabularyFilterName: Option[VocabularyFilterName] = None,
    languageCode: Option[zio.aws.transcribe.model.LanguageCode] = None,
    lastModifiedTime: Option[DateTime] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse = {
    import UpdateVocabularyFilterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
      .builder()
      .optionallyWith(
        vocabularyFilterName.map(value =>
          VocabularyFilterName.unwrap(value): java.lang.String
        )
      )(_.vocabularyFilterName)
      .optionallyWith(languageCode.map(value => value.unwrap))(_.languageCode)
      .optionallyWith(
        lastModifiedTime.map(value => DateTime.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .build()
  }
  def asReadOnly
      : zio.aws.transcribe.model.UpdateVocabularyFilterResponse.ReadOnly =
    zio.aws.transcribe.model.UpdateVocabularyFilterResponse
      .wrap(buildAwsValue())
}
object UpdateVocabularyFilterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.transcribe.model.UpdateVocabularyFilterResponse =
      zio.aws.transcribe.model.UpdateVocabularyFilterResponse(
        vocabularyFilterName.map(value => value),
        languageCode.map(value => value),
        lastModifiedTime.map(value => value)
      )
    def vocabularyFilterName: Option[VocabularyFilterName]
    def languageCode: Option[zio.aws.transcribe.model.LanguageCode]
    def lastModifiedTime: Option[DateTime]
    def getVocabularyFilterName: ZIO[Any, AwsError, VocabularyFilterName] =
      AwsError.unwrapOptionField("vocabularyFilterName", vocabularyFilterName)
    def getLanguageCode
        : ZIO[Any, AwsError, zio.aws.transcribe.model.LanguageCode] =
      AwsError.unwrapOptionField("languageCode", languageCode)
    def getLastModifiedTime: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
  ) extends zio.aws.transcribe.model.UpdateVocabularyFilterResponse.ReadOnly {
    override val vocabularyFilterName: Option[VocabularyFilterName] = scala
      .Option(impl.vocabularyFilterName())
      .map(value =>
        zio.aws.transcribe.model.primitives.VocabularyFilterName(value)
      )
    override val languageCode: Option[zio.aws.transcribe.model.LanguageCode] =
      scala
        .Option(impl.languageCode())
        .map(value => zio.aws.transcribe.model.LanguageCode.wrap(value))
    override val lastModifiedTime: Option[DateTime] = scala
      .Option(impl.lastModifiedTime())
      .map(value => zio.aws.transcribe.model.primitives.DateTime(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.transcribe.model.UpdateVocabularyFilterResponse
  ): zio.aws.transcribe.model.UpdateVocabularyFilterResponse.ReadOnly =
    new Wrapper(impl)
}
